@@ -22,7 +22,7 @@ int main(int argc, char *argv[])
     DApplication a(argc, argv);
 
     QTranslator translator;
-    if (translator.load("/usr/share/dde-session-ui/translations/dde-session-ui_" + QLocale::system().name())) {
+    if (translator.load(QLocale::system(), "dde-session-ui", "_", "/usr/share/dde-session-ui/translations")) {
         a.installTranslator(&translator);
     }
 
